@@ -26,22 +26,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 // Locale
 #include "notificationmanager.h"
-
-static const char* DESCRIPTION = I18N_NOOP("Light notification system for KDE4");
-static const char* VERSION = "0.1.0";
+#include "about.h"
 
 int main(int argc, char **argv)
 {
-    KAboutData about(
-        "colibri", 0, ki18n("Colibri"),
-        VERSION, ki18n(DESCRIPTION),
-        KAboutData::License_GPL,
-        ki18n("(C) 2009 Aurélien Gâteau"),
-        KLocalizedString(), 0, "agateau@kde.org");
-    about.addAuthor(ki18n("Aurélien Gâteau"), KLocalizedString(), "agateau@kde.org");
-    KCmdLineArgs::init(argc, argv, &about);
+    KAboutData* about = createAboutData();
+    KCmdLineArgs::init(argc, argv, about);
 
     KApplication app;
     Colibri::NotificationManager manager;
+    if (!manager.connectOnDBus()) {
+        return 1;
+    }
     return app.exec();
 }
