@@ -53,6 +53,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Local
 #include "label.h"
 
+// Enable this to quit colibri after one notification. Useful for memchecking
+// with Valgrind.
+//#define QUIT_AFTER_ONE
+
 namespace Colibri
 {
 
@@ -82,7 +86,8 @@ static const qreal NON_COMPOSITED_OPACITY_THRESHOLD = .4;
 // State
 ////////////////////////////////////////////////////:
 State::State(NotificationWidget* widget)
-: mNotificationWidget(widget)
+: QObject(widget)
+, mNotificationWidget(widget)
 {}
 
 void State::switchToState(State* state)
@@ -112,7 +117,7 @@ public:
 FadeInState::FadeInState(NotificationWidget* widget)
 : State(widget)
 {
-    QPropertyAnimation* anim = new QPropertyAnimation(widget, "fadeOpacity");
+    QPropertyAnimation* anim = new QPropertyAnimation(widget, "fadeOpacity", this);
     anim->setDuration(DEFAULT_FADE_IN_TIMEOUT);
     // FIXME: Adjust duration according to current opacity
     anim->setStartValue(mNotificationWidget->fadeOpacity());
@@ -160,7 +165,7 @@ void VisibleState::onMouseLeave()
 FadeOutState::FadeOutState(NotificationWidget* widget)
 : State(widget)
 {
-    QPropertyAnimation* anim = new QPropertyAnimation(widget, "fadeOpacity");
+    QPropertyAnimation* anim = new QPropertyAnimation(widget, "fadeOpacity", this);
     anim->setDuration(DEFAULT_FADE_OUT_TIMEOUT);
     anim->setStartValue(1.);
     anim->setEndValue(0.);
@@ -487,6 +492,9 @@ void NotificationWidget::updateMouseOverOpacity()
 void NotificationWidget::emitClosed()
 {
     emit closed(mId, mCloseReason);
+#ifdef QUIT_AFTER_ONE
+    QCoreApplication::exit();
+#endif
 }
 
 } // namespace
