@@ -48,10 +48,15 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void updateUnmanagedWidgetChangeState();
+    void updateStateInformation();
+    void startColibri();
+    void preview();
+    void fillScreenComboBox();
 
 private:
     Config* mConfig;
     Ui::ControlModule* mUi;
+    uint mLastPreviewId;
 };
 
 } // namespace
